package com.fs.live.service;

import java.util.List;
import com.fs.live.domain.LiveCouponIssue;
import com.fs.live.param.CouponPO;

/**
 * 优惠券领取Service接口
 *
 * @author fs
 * @date 2025-09-30
 */
public interface ILiveCouponIssueService
{
    /**
     * 查询优惠券领取
     *
     * @param id 优惠券领取ID
     * @return 优惠券领取
     */
    public LiveCouponIssue selectLiveCouponIssueById(Long id);

    /**
     * 查询优惠券领取列表
     *
     * @param liveCouponIssue 优惠券领取
     * @return 优惠券领取集合
     */
    public List<LiveCouponIssue> selectLiveCouponIssueList(LiveCouponIssue liveCouponIssue);

    /**
     * 新增优惠券领取
     *
     * @param liveCouponIssue 优惠券领取
     * @return 结果
     */
    public int insertLiveCouponIssue(LiveCouponIssue liveCouponIssue);

    /**
     * 修改优惠券领取
     *
     * @param liveCouponIssue 优惠券领取
     * @return 结果
     */
    public int updateLiveCouponIssue(LiveCouponIssue liveCouponIssue);

    /**
     * 批量删除优惠券领取
     *
     * @param ids 需要删除的优惠券领取ID
     * @return 结果
     */
    public int deleteLiveCouponIssueByIds(Long[] ids);

    /**
     * 删除优惠券领取信息
     *
     * @param id 优惠券领取ID
     * @return 结果
     */
    public int deleteLiveCouponIssueById(Long id);

    List<LiveCouponIssue> selectLiveCouponIssueUserByCouponPO(CouponPO coupon);

    List<LiveCouponIssue> curCoupon(CouponPO coupon);

    LiveCouponIssue selectLiveCouponIssueByCouponId(Long id);
}
